=========================
 Invenio-Celery v1.0.0b3
=========================

Invenio-Celery v1.0.0b3 was released on August 7, 2017.

About
-----

Integration layer between Celery and Invenio.

Installation
------------

   $ pip install invenio-celery==1.0.0b3

Documentation
-------------

   https://invenio-celery.readthedocs.io/

Happy hacking and thanks for flying Invenio-Celery.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: https://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-celery
|   URL: http://inveniosoftware.org
